@@ -14,7 +14,9 @@ setClass("GRangesList",
     )
 )
 
-setClassUnion("GenomicRangesORGRangesList", c("GenomicRanges", "GRangesList"))
+### Note that rtracklayer also defines GenomicRanges_OR_GenomicRangesList.
+### Do we need the 2 union classes?
+setClassUnion("GenomicRanges_OR_GRangesList", c("GenomicRanges", "GRangesList"))
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -63,7 +65,7 @@ GRangesList <- function(...)
             stop("all elements in '...' must be GRanges objects")
         unlistData <- suppressWarnings(do.call("c", unname(listData)))
     }
-    relist(unlistData, PartitioningByEnd(listData))
+    relist(unlistData, listData)
 }
 
 ### Typically, the field values will come from a file that needs to be loaded
@@ -369,7 +371,7 @@ setMethod("seqinfo", "GRangesList", function(x) seqinfo(x@unlistData))
 
 ### NOT exported but used in GenomicAlignments package.
 set_GRangesList_seqinfo <-
-    function(x, new2old=NULL, force=FALSE,
+    function(x, new2old=NULL,
              pruning.mode=c("error", "coarse", "fine", "tidy"),
              value)
 {
@@ -377,7 +379,7 @@ set_GRangesList_seqinfo <-
     if (!is(value, "Seqinfo"))
         stop("the supplied 'seqinfo' must be a Seqinfo object")
     dangling_seqlevels <- GenomeInfoDb:::getDanglingSeqlevels(x,
-                              new2old=new2old, force=force,
+                              new2old=new2old,
                               pruning.mode=pruning.mode,
                               seqlevels(value))
     if (length(dangling_seqlevels) != 0L) {
@@ -583,6 +585,13 @@ showList <- function(object, showFunction, print.classinfo)
 }
 
 setMethod("show", "GRangesList",
-    function(object) showList(object, show_GenomicRanges, TRUE)
+    function(object)
+    {
+        if (is(object@unlistData, "GPos"))
+            showFunction <- show_GPos
+        else
+            showFunction <- show_GenomicRanges
+        showList(object, showFunction, print.classinfo=TRUE)
+    }
 )
 
