@@ -14,7 +14,7 @@ setClass("GenomicRanges",
     )
 )
 
-setClassUnion("GenomicRangesORmissing", c("GenomicRanges", "missing"))
+setClassUnion("GenomicRanges_OR_missing", c("GenomicRanges", "missing"))
 
 ### The code in this file will work out-of-the-box on 'x' as long as
 ### seqnames(x), ranges(x), strand(x), seqlengths(x), seqinfo(),
@@ -140,8 +140,8 @@ make_out_of_bound_warning_msg <- function(x, idx, suggest.trim)
 
 .valid.GenomicRanges.ranges <- function(x)
 {
-    if (class(ranges(x)) != "IRanges")
-        return("'ranges(x)' must be an IRanges instance")
+    if (!(class(ranges(x)) %in% c("IRanges", "IPos")))
+        return("'ranges(x)' must be an IRanges or IPos instance")
     NULL
 }
 
@@ -231,7 +231,7 @@ setMethod("as.character", "GenomicRanges",
             stop(wmsg("'ignore.strand' must be TRUE or FALSE"))
         if (length(x) == 0L)
             return(setNames(character(0), names(x)))
-        ans <- paste0(seqnames(x), ":", start(x), "-", end(x))
+        ans <- paste0(seqnames(x), ":", as.character(ranges(x)))
         names(ans) <- names(x)
         if (ignore.strand)
             return(ans)
@@ -362,26 +362,10 @@ setReplaceMethod("ranges", "GenomicRanges",
     }
 )
 
-normargGenomicRangesStrand <- function(strand, n)
-{
-    if (!is(strand, "Rle"))
-        strand <- Rle(strand)
-    if (!is.factor(runValue(strand))
-     || !identical(levels(runValue(strand)), levels(strand())))
-        runValue(strand) <- strand(runValue(strand))
-    k <- length(strand)
-    if (k != n) {
-        if (k != 1L && (k == 0L || k > n || n %% k != 0L))
-            stop("supplied 'strand' has ", k, " elements (", n, " expected)")
-        strand <- rep(strand, length.out=n)
-    }
-    strand
-}
-
 setReplaceMethod("strand", "GenomicRanges",
     function(x, value)
     {
-        value <- normargGenomicRangesStrand(value, length(x))
+        value <- normalize_strand_replacement_value(value, x)
         x <- update(x, strand=value, check=FALSE)
         msg <- .valid.GenomicRanges.strand(x)
         if (!is.null(msg))
@@ -393,7 +377,7 @@ setReplaceMethod("strand", "GenomicRanges",
 ### Does NOT suppoprt pruning mode "fine". Pruning modes "coarse" and "tidy"
 ### are equivalent on a GenomicRanges object.
 set_GenomicRanges_seqinfo <-
-    function(x, new2old=NULL, force=FALSE,
+    function(x, new2old=NULL,
              pruning.mode=c("error", "coarse", "fine", "tidy"),
              value)
 {
@@ -404,7 +388,7 @@ set_GenomicRanges_seqinfo <-
     if (!is(value, "Seqinfo"))
         stop("the supplied 'seqinfo' must be a Seqinfo object")
     dangling_seqlevels <- GenomeInfoDb:::getDanglingSeqlevels(x,
-                              new2old=new2old, force=force,
+                              new2old=new2old,
                               pruning.mode=pruning.mode,
                               seqlevels(value))
     if (length(dangling_seqlevels) != 0L) {
