@@ -15,18 +15,7 @@ setMethod("shift", "GenomicRanges",
     function(x, shift=0L, use.names=TRUE)
     {
         new_ranges <- shift(ranges(x), shift=shift, use.names=use.names)
-        ranges(x) <- new_ranges
-        x
-    }
-)
-
-### Overwrite above method with optimized method for GPos objects.
-### A GPos object cannot hold names so the 'use.names' arg has no effect.
-setMethod("shift", "GPos",
-    function(x, shift=0L, use.names=TRUE)
-    {
-        x@pos_runs <- callGeneric(x@pos_runs, shift=shift)
-        x
+        update(x, ranges=new_ranges)
     }
 )
 
