@@ -260,13 +260,12 @@ test_GRanges_mcols <- function()
     checkIdentical(GRanges(), gr0)
     mcols(gr1) <- mcols(gr1)  # no-op
     checkIdentical(.make_TARGET_GRanges(), gr1)
-    checkException(mcols(gr1) <- DataFrame(strand=1:length(gr)),
-                   silent=TRUE)
     checkException(mcols(gr1) <- DataFrame(score=letters),
                    silent=TRUE)
 
     mcols(gr1) <- NULL
-    checkIdentical(new("DataFrame", nrows=length(gr1)), mcols(gr1))
+    checkIdentical(S4Vectors:::make_zero_col_DataFrame(length(gr1)),
+                   mcols(gr1))
 
     val <- DataFrame(x=1:length(gr1), y = head(letters, length(gr1)))
     mcols(gr1) <- val
