@@ -21,26 +21,54 @@ test_GRangesList_construction <- function() {
     checkTrue(validObject(new("GRangesList")))
     checkTrue(validObject(GRangesList()))
     checkTrue(validObject(GRangesList(GRanges())))
+    checkTrue(validObject(GRangesList(GRanges(), GRanges())))
+    checkTrue(validObject(GRangesList(list(GRanges(), GRanges()))))
     checkTrue(validObject(GRangesList(a = GRanges())))
     checkTrue(validObject(make_test_GRangesList()))
 }
 
-test_GRangesList_coercion <- function() {
-    ## RangedDataList -> GRangesList
-    rd <-
-      RangedData(space = c(1,1,2),
-                 ranges = IRanges(1:3,4:6, names = head(letters,3)),
-                 strand = strand(c("+", "-", "*")),
-                 score = c(10L,2L,NA))
-    rdl <- RangedDataList(a = rd, b = rd)
-    gr <-
-      GRanges(seqnames = c(1,1,2),
-              ranges = IRanges(1:3,4:6, names = head(letters,3)),
-              strand = strand(c("+", "-", "*")),
-              score = c(10L,2L,NA))
-    grl <- GRangesList(a = gr, b = gr)
-    checkIdentical(as(rdl, "GRangesList"), grl)
+test_GRangesList_getters <- function() {
+    grl <- make_test_GRangesList()
+    checkIdentical(seqnames(grl), RleList(lapply(grl, seqnames), compress=TRUE))
+    checkIdentical(ranges(grl), IRangesList(lapply(grl, ranges)))
+    checkIdentical(strand(grl), RleList(lapply(grl, strand), compress=TRUE))
+    checkIdentical(seqlengths(grl), seqlengths(grl@unlistData))
+    checkIdentical(mcols(grl, level="within"),
+                   SplitDataFrameList(lapply(grl, mcols)))
+}
 
+test_GRangesList_setters <- function() {
+    grl0 <- GRangesList(A=GRanges("chr2", IRanges(3:2, 5)),
+                        B=GRanges(c("chr2", "chrMT"), IRanges(7:6, 15)),
+                        C=GRanges(c("chrY", "chrMT"), IRanges(17:16, 25)),
+                        D=GRanges())
+
+    current <- grl0
+    seqlevels(current, pruning.mode="coarse") <- c("chr2", "chr5")
+    target <- GRangesList(A=GRanges("chr2", IRanges(3:2, 5),
+                                    seqinfo=Seqinfo(c("chr2", "chr5"))),
+                          D=GRanges())
+    checkIdentical(target, current)
+
+    current <- grl0
+    seqlevels(current, pruning.mode="fine") <- c("chr2", "chr5")
+    target <- GRangesList(A=GRanges("chr2", IRanges(3:2, 5),
+                                    seqinfo=Seqinfo(c("chr2", "chr5"))),
+                          B=GRanges("chr2", IRanges(7, 15)),
+                          C=GRanges(),
+                          D=GRanges())
+    checkIdentical(target, current)
+
+    current <- grl0
+    seqlevels(current, pruning.mode="tidy") <- c("chr2", "chr5")
+    target <- GRangesList(A=GRanges("chr2", IRanges(3:2, 5),
+                                    seqinfo=Seqinfo(c("chr2", "chr5"))),
+                          B=GRanges("chr2", IRanges(7, 15)),
+                          D=GRanges())
+    checkIdentical(target, current)
+}
+
+test_GRangesList_coercion <- function() {
     ## as.data.frame
     gr1 <-
       GRanges(seqnames = c(1,1,2),
@@ -65,16 +93,6 @@ test_GRangesList_coercion <- function() {
     checkIdentical(as.data.frame(grl), df)
 }
 
-test_GRangesList_accessors <- function() {
-    grl <- make_test_GRangesList()
-    checkIdentical(seqnames(grl), RleList(lapply(grl, seqnames), compress=TRUE))
-    checkIdentical(ranges(grl), IRangesList(lapply(grl, ranges)))
-    checkIdentical(strand(grl), RleList(lapply(grl, strand), compress=TRUE))
-    checkIdentical(seqlengths(grl), seqlengths(grl@unlistData))
-    checkIdentical(mcols(grl, level="within"),
-                   SplitDataFrameList(lapply(grl, mcols)))
-}
-
 test_GRangesList_RangesList <- function() {
     grl <- make_test_GRangesList()
     checkIdentical(start(grl), IntegerList(lapply(grl, start)))
@@ -115,10 +133,10 @@ test_GRangesList_Vector <- function() {
     checkIdentical(grl[,"score"],
                    GRangesList(lapply(grl, function(x) x[,"score"])))
     checkIdentical(grl[seqnames(grl) == "chr2",],
-                   GRangesList(lapply(grl, function(x) 
+                   GRangesList(lapply(grl, function(x)
                                       x[seqnames(x) == "chr2",])))
     checkIdentical(grl[seqnames(grl) == "chr2", "score"],
-                   GRangesList(lapply(grl, function(x) 
+                   GRangesList(lapply(grl, function(x)
                                       x[seqnames(x) == "chr2", "score"])))
 
     checkIdentical(GRangesList(), c(GRangesList(), GRangesList()))
